@@ -5,7 +5,7 @@ import platform
 
 from requests import Session
 from requests.adapters import HTTPAdapter
-from requests.packages.urllib3.util.retry import Retry
+from requests.packages.urllib3.util.retry import Retry # type: ignore
 
 from launchable.version import __version__
 from .authentication import get_org_workspace, authentication_headers
